/* @(#) definition of packet-io functions for udpxy
 *
 * Copyright 2008 Pavel V. Cherenkov
 *
 *  This file is part of udpxy.
 *
 *  udpxy is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  udpxy is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with udpxy.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef UDPXY_DPKTH_02182008
#define UDPXY_DPKTH_02182008

#include <stdio.h>
#include "udpxy.h"

/* data-stream format type */
typedef enum {
    DT_FIRST   = -1,

    DT_UNKNOWN,     /* no assumptions */
    DT_TS,          /* MPEG-TS */
    DT_RTP_TS,      /* RTP over MPEG-TS */
    DT_UDS,         /* UDS file format */
    DT_RAW,         /* read AS-IS */

    DT_LAST
} upxfmt_t;

#ifdef __cplusplus
extern "C" {
#endif

/* return human-readable name of file/stream format
*/
const char* fmt2str( upxfmt_t fmt );


/* determine type of stream saved in file
 */
upxfmt_t
get_fstream_type( int fd, FILE* log );

/* determine type of stream in memory
 */
upxfmt_t
get_mstream_type( const char* data, size_t len, FILE* log );


/* read record of one of the supported types from file
 */
ssize_t
read_frecord( int fd, char* data, const size_t len,
             upxfmt_t* stream_type, FILE* log );


/* write record after converting it from source into destination
 * format
 */
ssize_t
write_frecord( int fd, const char* data, size_t len,
              upxfmt_t sfmt, upxfmt_t dfmt, FILE* log );


#ifdef __cplusplus
}
#endif

#endif /* UDPXY_DPKTH_02182008 */

/* __EOF__ */

