/* @(#) option definitions and associated structures for udpxy
 *
 * Copyright 2008 Pavel V. Cherenkov
 *
 *  This file is part of udpxy.
 *
 *  udpxy is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  udpxy is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with udpxy.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef UOPT_H_0215082300
#define UOPT_H_0215082300

#include <stdio.h>
#include <sys/types.h>

static const int MIN_CLIENT_COUNT       = 1;
static const int MAX_CLIENT_COUNT       = 16;
static const int DEFAULT_CLIENT_COUNT   = 3;

static const size_t MIN_MCACHE_K    = 4;
static const size_t MAX_MCACHE_K    = 2048;
static const size_t DEFAULT_CACHE_K = 64;

/* udpxy options
 */
struct udpxy_opt {
    flag_t  is_verbose;     /* verbose output on/off                */
    flag_t  cl_tpstat;      /* client reports throughput stats      */
    int     nice_incr;      /* value to increment nice by           */
    size_t  rbuf_K;         /* size of read buffer in Kb            */
    int     rbuf_msgs;      /* max msgs in read buffer (-1 = all)   */
    int     max_clients;    /* max clients to accept                */

    char*  srcfile;         /* file to read (video stream) from     */
    char*  dstfile;         /* file to save (video stream) to       */
};

#ifdef __cplusplus
    extern "C" {
#endif

/* populate options with default/initial values
 */
void
init_uopt( struct udpxy_opt* uo );

/* release resources allocated for udpxy options
 */
void
free_uopt( struct udpxy_opt* uo );

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* UOPT_H_0215082300 */

/* __EOF__ */

