/* @(#) interface to utility functions for udpxy
 *
 * Copyright 2008 Pavel V. Cherenkov
 *
 *  This file is part of udpxy.
 *
 *  udpxy is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  udpxy is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with udpxy.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef UTILH_UDPXY_200712181853
#define UTILH_UDPXY_200712181853

#include <sys/types.h>

#ifdef __cplusplus
extern "C" {
#endif

/* write buffer to a file
 */
ssize_t
save_buffer( const void* buf, size_t len, const char* filename );


/* start process as a daemon
 *
 */
#define DZ_STDIO_OPEN  1   /* do not close STDIN, STDOUT, STDERR */
int
daemonize(int options);


/* multiplex error output to custom log
 * and syslog
 */
void
mperror( FILE* fp, int err, const char* str );


/* create and lock file with process's ID
 */
int
make_pidfile( const char* fpath, pid_t pid, FILE* log );


/* write path to application's pidfile into the the buffer
 * (fail of destination directory is not writable)
 */
int
set_pidfile( const char* appname, char* buf, size_t len );

/* write buffer to designated socket/file
 */
ssize_t
write_buf( int fd, const char* data, const ssize_t len, FILE* log );

/* read data chunk of designated size into buffer
 */
ssize_t
read_buf( int fd, char* buf, const ssize_t len, FILE* log );

/* output hex dump of a memory fragment
 */
void
hex_dump( const char* msg, const char* data, size_t len, FILE* log );

/* check for expected size, complain if not matched
 */
int
sizecheck( const char* msg, ssize_t expct, ssize_t len,
              FILE* log, const char* func );

/* check for a potential buffer overrun by
 * evaluating target buffer and the portion
 * of that buffer to be accessed
 */
int
buf_overrun( const char* buf, size_t buflen,
             size_t offset, size_t dlen,
             FILE* log );


#ifdef __cplusplus
}
#endif

#endif /* UTILH_UDPXY_200712181853 */

/* __EOF__ */

